@@ -97,15 +97,9 @@ def do_stuff(args):
             cluster = ComputeTarget(workspace=ws, name=cluster_name)
         except : 
             
-            go_config=input("workspace doesn't exist yet. Do you want to create it? (Y/N)")
-            while go_config.lower() not in ["y","n"]:
-                go_config=input("invalid input, please tell : do you want to launch the config (Y/N)")
-            if go_config.lower()=="y":
-                from config import config
-                config()
-            else :
-                logging.info("ok, exiting")
-                return 1
+            
+            from config import config
+            ws,cluster_name=config(args)
             
             cluster = ComputeTarget(workspace=ws, name=cluster_name)
         
@@ -243,10 +237,17 @@ def main():
     ap.add_argument('--data',help='url of the data folder')
     ap.add_argument("--project_folder", "-p",help='folder where the files will be')
     ap.add_argument('--framework','-f',help="TensorFlow, PyTorch, Chainer, and Python are supported ")
-    ap.add_argument('--cluster_name','-c',help="Name of the cluster on which to do the training",default="basic")
+    ap.add_argument('--region','-r',help='Azure region where the compute happens',default="westeurope")
     ap.add_argument("--storage_account","-d",help='account name for location of data (must be blob here)')
     ap.add_argument("--storage_key",help='storage key')
     ap.add_argument("--storage_path",help='container in the storage account where the data is')
+    ap.add_argument('--subscription_id',help='id of the subscription on which the service will be provider')
+    ap.add_argument('--resource_group','-g',help='id of the resource group on which the service will be provider',default="amlfbp")
+    ap.add_argument('--cluster_name','-c',help='name of the cluster on which to work',default="basic")
+    ap.add_argument('--workspace_name','-w',help='id of the workspace',default="default")
+    ap.add_argument('--vm_size',help='type of VM on which to run the compute',default="STANDARD_D2_V2")
+    ap.add_argument('--max_nodes','-n',help='maximum number of nodes allowed on the cluster',default=2)
+
     args = vars(ap.parse_args())
 
     import json 
